hfst-altlab
===========

A wrapper on the [hfst][] python package, currently working as a replacement for [hfst-optimized-lookup][], built for [itwêwina][].

This module helps to use both analyser and generator FSTs for multiple linguistic uses and language tools.

[itwêwina]: https://itwewina.altlab.app
[hfst-optimized-lookup]: https://github.com/UAlbertaALTLab/hfst-optimized-lookup
[hfst]: https://pypi.org/project/hfst/

Languages currently supported:
  - Python

[hfst] is a great toolkit with all sorts of functionality, and is
indispensable for building FSTs, but for various applications that only
want to do unweighted hfstol lookups, this package may be easier to use.

[hfst]: https://github.com/hfst/hfst

[morphodict]: https://github.com/UAlbertaALTLab/morphodict
